# Contributing to `yads`

We welcome contributions to `yads`! Whether you're fixing a bug, adding a feature, or improving documentation, your help is appreciated. Please refer to our [contributors guide](https://docs.texel.sh/yads/develop/contributing/) for information on how to submit your PR.
